Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(501)

Unified Diff: ui/app_list/views/app_list_view.h

Issue 2802903003: Implementation of a full screen app list and re-alphabetized switches (Closed)
Patch Set: Addressed comments, added my tests to the filter, and refactored! Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/app_list/views/app_list_view.h
diff --git a/ui/app_list/views/app_list_view.h b/ui/app_list/views/app_list_view.h
index fb3b061ebef8785d33a8e979000d097a1cbf251c..8f4bad4847fb4fb250fc050dac8fd56cdbc5d11e 100644
--- a/ui/app_list/views/app_list_view.h
+++ b/ui/app_list/views/app_list_view.h
@@ -38,16 +38,22 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDialogDelegateView,
explicit AppListView(AppListViewDelegate* delegate);
~AppListView() override;
- // Initializes the widget.
- void InitAsBubble(gfx::NativeView parent, int initial_apps_page);
+ // Initializes the widget as a bubble or fullscreen view.
+ void Initialize(gfx::NativeView parent,
sky 2017/04/20 21:08:45 Again, can there be just one Initialize() function
newcomer 2017/04/21 19:51:22 Done!
+ int initial_apps_page,
+ const gfx::Rect& display_work_area_bounds);
+
+ // Initializes the widget as a bubble.
+ void Initialize(gfx::NativeView parent,
+ int initial_apps_page);
void SetBubbleArrow(views::BubbleBorder::Arrow arrow);
- void SetAnchorPoint(const gfx::Point& anchor_point);
+ void MaybeSetAnchorPoint(const gfx::Point& anchor_point);
// If |drag_and_drop_host| is not NULL it will be called upon drag and drop
// operations outside the application list. This has to be called after
// InitAsBubble was called since the app list object needs to exist so that
// it can set the host.
void SetDragAndDropHostOfCurrentAppList(
ApplicationDragAndDropHost* drag_and_drop_host);
@@ -69,6 +75,7 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDialogDelegateView,
// Overridden from views::View:
gfx::Size GetPreferredSize() const override;
void OnPaint(gfx::Canvas* canvas) override;
+ const char* GetClassName() const override;
// WidgetDelegate overrides:
bool ShouldHandleSystemCommands() const override;
@@ -93,6 +100,14 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDialogDelegateView,
void InitChildWidgets();
+ // Initializes the widget for fullscreen mode.
+ void InitializeFullscreen(gfx::NativeView parent,
+ int initial_apps_page,
vadimt 2017/04/20 20:21:35 Indent doesn't look right...
newcomer 2017/04/21 19:51:22 git cl format, done!
+ const gfx::Rect& display_work_area_bounds);
+
+ // Initializes the widget as a bubble.
+ void InitializeBubble(gfx::NativeView parent, int initial_apps_page);
+
// Overridden from views::BubbleDialogDelegateView:
void OnBeforeBubbleWidgetInit(views::Widget::InitParams* params,
views::Widget* widget) const override;
@@ -117,8 +132,8 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDialogDelegateView,
SpeechView* speech_view_;
views::View* search_box_focus_host_; // Owned by the views hierarchy.
- views::Widget* search_box_widget_; // Owned by the app list's widget.
- SearchBoxView* search_box_view_; // Owned by |search_box_widget_|.
+ views::Widget* search_box_widget_; // Owned by the app list's widget.
+ SearchBoxView* search_box_view_; // Owned by |search_box_widget_|.
// A semi-transparent white overlay that covers the app list while dialogs are
// open.
@@ -38,16 +38,22 @@ class APP_LIST_EXPORT AppListView : public views::BubbleDialogDelegateView,
// If |drag_and_drop_host| is not NULL it will be called upon drag and drop
// operations outside the application list. This has to be called after
- // InitAsBubble was called since the app list object needs to exist so that
+ // Initialize was called since the app list object needs to exist so that
// it can set the host.
void SetDragAndDropHostOfCurrentAppList(

Powered by Google App Engine
This is Rietveld 408576698